@@ -1,16 +1,13 @@
 {-# LANGUAGE CPP #-}
-{-# LANGUAGE KindSignatures #-}
-
-#if __GLASGOW_HASKELL__ >= 706
 {-# LANGUAGE ConstraintKinds #-}
+{-# LANGUAGE KindSignatures #-}
 {-# LANGUAGE ExplicitNamespaces #-}
-#endif
 
 #if __GLASGOW_HASKELL__ >= 806
 {-# LANGUAGE NoStarIsType #-}
 #endif
 
-{-# OPTIONS_GHC -fno-warn-deprecations #-}
+{-# OPTIONS_GHC -Wno-deprecations #-}
 
 {-|
 Exports modules that Data.Orphans needs. Because Data.Orphans uses several modules
@@ -21,7 +18,7 @@ This makes it much easier to be -Wall-compliant.
 Note that this module does not export any modules that could introduce name clashes.
 -}
 module Data.Orphans.Prelude
-#if MIN_VERSION_base(4,18,0)
+#if !defined(__GLASGOW_HASKELL__) || MIN_VERSION_base(4,21,0)
     () where
 #else
     ( module OrphansPrelude
@@ -42,21 +39,26 @@ import Control.Category as OrphansPrelude hiding ((.), id)
 import Control.Concurrent.QSem as OrphansPrelude
 import Control.Monad as OrphansPrelude hiding (mapM, sequence)
 import Control.Monad.Fix as OrphansPrelude
+import Control.Monad.Zip as OrphansPrelude
 
+import Data.Bifunctor as OrphansPrelude
 import Data.Bits as OrphansPrelude
 import Data.Char as OrphansPrelude
 import Data.Complex as OrphansPrelude (Complex(..))
 import Data.Data as OrphansPrelude (Data(..), Constr, DataType, mkConstr, mkDataType)
 import Data.Fixed as OrphansPrelude
+import Data.Functor.Classes as OrphansPrelude
+import Data.Functor.Compose as OrphansPrelude
+import Data.Functor.Identity as OrphansPrelude
 import Data.Int as OrphansPrelude
 import Data.List as OrphansPrelude (genericLength)
-import Data.Monoid as OrphansPrelude
-  hiding ( Any(..)
-# if MIN_VERSION_base(4,5,0)
-         , (<>)
-# endif
-         )
+import Data.Monoid as OrphansPrelude hiding (Any(..), (<>))
+import Data.Ord as OrphansPrelude (Down(..))
+import Data.Proxy as OrphansPrelude
+import Data.Semigroup as OrphansPrelude (stimesMonoid)
 import Data.String as OrphansPrelude (IsString)
+import Data.Type.Coercion as OrphansPrelude (Coercion, TestCoercion)
+import Data.Type.Equality as OrphansPrelude ((:~:)(..), TestEquality(..))
 import Data.Typeable as OrphansPrelude (Typeable)
 import Data.Version as OrphansPrelude
 import Data.Word as OrphansPrelude
@@ -71,15 +73,24 @@ import GHC.Arr as OrphansPrelude (Ix(..))
 import GHC.Base as OrphansPrelude
 import GHC.Conc as OrphansPrelude
 import GHC.Desugar as OrphansPrelude (AnnotationWrapper)
+import GHC.Exts as OrphansPrelude (IsList(..), Ptr(..))
+import GHC.Fingerprint as OrphansPrelude
 import GHC.ForeignPtr as OrphansPrelude
+import GHC.GHCi as OrphansPrelude
 import GHC.IO.Buffer as OrphansPrelude
 import GHC.IO.BufferedIO as OrphansPrelude (BufferedIO)
 import GHC.IO.Device as OrphansPrelude (IODevice, IODeviceType(..), RawIO)
 import GHC.IO.Encoding as OrphansPrelude
+import GHC.IO.Encoding.Failure as OrphansPrelude
 import GHC.IO.Handle as OrphansPrelude
 import GHC.IO.Handle.Types as OrphansPrelude
+import GHC.Read as OrphansPrelude (expectP, paren)
 import GHC.Real as OrphansPrelude (Ratio(..), (%))
 import GHC.ST as OrphansPrelude
+import GHC.Show as OrphansPrelude (appPrec)
+import GHC.Stack as OrphansPrelude
+import GHC.Stats as OrphansPrelude
+import GHC.TypeLits as OrphansPrelude hiding (type (*))
 
 import Numeric as OrphansPrelude (showHex)
 
@@ -90,6 +101,7 @@ import System.Posix.Types as OrphansPrelude
 
 import Text.Printf as OrphansPrelude
 import Text.Read as OrphansPrelude
+import Text.Read.Lex as OrphansPrelude (Number)
 
 import Unsafe.Coerce as OrphansPrelude (unsafeCoerce)
 
@@ -97,58 +109,11 @@ import Unsafe.Coerce as OrphansPrelude (unsafeCoerce)
 import GHC.IO.Encoding.CodePage.Table as OrphansPrelude
 # endif
 
-# if MIN_VERSION_base(4,4,0)
-import Control.Monad.Zip as OrphansPrelude
-import GHC.Fingerprint as OrphansPrelude
-import GHC.IO.Encoding.Failure as OrphansPrelude
-
-#  if !defined(mingw32_HOST_OS) && !defined(__GHCJS__)
+# if !defined(mingw32_HOST_OS) && !defined(__GHCJS__)
 import GHC.Event as OrphansPrelude
-#   if !(MIN_VERSION_base(4,7,0))
-      hiding (step)
-#   endif
-#  endif
 # endif
 
-# if MIN_VERSION_base(4,5,0)
-import GHC.Stack as OrphansPrelude
-import GHC.Stats as OrphansPrelude
-# endif
-
-# if MIN_VERSION_base(4,6,0)
-import Data.Ord as OrphansPrelude (Down(..))
-import GHC.GHCi as OrphansPrelude
-import GHC.TypeLits as OrphansPrelude hiding (type (*))
-# else
-import GHC.Exts as OrphansPrelude (Down(..))
-# endif
-
-# if MIN_VERSION_base(4,6,0) && !(MIN_VERSION_base(4,8,2))
-import GHC.IP as OrphansPrelude
-# endif
-
-# if MIN_VERSION_base(4,7,0)
-import Data.Proxy as OrphansPrelude
-import Data.Type.Coercion as OrphansPrelude (Coercion, TestCoercion)
-import Data.Type.Equality as OrphansPrelude ((:~:)(..), TestEquality(..))
-import GHC.Exts as OrphansPrelude (IsList(..))
-import Text.Read.Lex as OrphansPrelude (Number)
-# else
-import Control.Concurrent.SampleVar as OrphansPrelude
-# endif
-
-# if MIN_VERSION_base(4,8,0)
-import Data.Bifunctor as OrphansPrelude
-import Data.Functor.Identity as OrphansPrelude
-#endif
-
-# if MIN_VERSION_base(4,9,0)
-import Data.Functor.Classes as OrphansPrelude
-import Data.Functor.Compose as OrphansPrelude
-import Data.Semigroup as OrphansPrelude (stimesMonoid)
-# endif
-
-# if MIN_VERSION_base(4,9,0) && !(MIN_VERSION_base(4,12,0))
+# if !(MIN_VERSION_base(4,12,0))
 import Data.List.NonEmpty as OrphansPrelude (NonEmpty(..))
 import Data.Semigroup as OrphansPrelude (Semigroup(..))
 # endif
@@ -163,11 +128,7 @@ import GHC.Generics as OrphansPrelude ( Generic(..), Generic1(..)
                                       , Generically(..), Generically1(..) )
 # endif
 
-# if MIN_VERSION_base(4,4,0)
 realPart, imagPart :: Complex a -> a
-# else
-realPart, imagPart :: RealFloat a => Complex a -> a
-# endif
 realPart (x :+ _) = x
 imagPart (_ :+ y) = y
 
